Metadata-Version: 1.0
Name: wot-tms-suhomlin
Version: 1.0
Summary: UNKNOWN
Home-page: UNKNOWN
Author: Nikita Suhomlin
Author-email: nekit_suhomlinkas@tut.by
License: MIT
Description: UNKNOWN
Platform: UNKNOWN
